"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var extract_field_resolvers_from_object_type_1 = require("./extract-field-resolvers-from-object-type");
var get_definition_nodes_from_typedefs_1 = require("./get-definition-nodes-from-typedefs");
var utils_1 = require("../epoxy/typedefs-mergers/utils");
function extractResolversFromSchema(schema, options) {
    var resolvers = {};
    var typeMap = schema.getTypeMap();
    var selectedTypeNames;
    if (options && options.selectedTypeDefs) {
        var definitionNodes = get_definition_nodes_from_typedefs_1.getDefinitionNodesFromTypeDefs(options.selectedTypeDefs);
        for (var _i = 0, definitionNodes_1 = definitionNodes; _i < definitionNodes_1.length; _i++) {
            var definitionNode = definitionNodes_1[_i];
            if (utils_1.isGraphQLType(definitionNode) || utils_1.isGraphQLTypeExtension(definitionNode)) {
                selectedTypeNames = selectedTypeNames || [];
                selectedTypeNames.push(definitionNode.name.value);
            }
        }
    }
    for (var typeName in typeMap) {
        if (!typeName.startsWith('__')) {
            var typeDef = typeMap[typeName];
            if (selectedTypeNames && !selectedTypeNames.includes(typeName)) {
                continue;
            }
            if (typeDef instanceof graphql_1.GraphQLScalarType) {
                resolvers[typeName] = typeDef;
            }
            else if (typeDef instanceof graphql_1.GraphQLObjectType || typeDef instanceof graphql_1.GraphQLInterfaceType) {
                resolvers[typeName] = extract_field_resolvers_from_object_type_1.extractFieldResolversFromObjectType(typeDef, {
                    selectedTypeDefs: options && options.selectedTypeDefs
                });
            }
        }
    }
    return resolvers;
}
exports.extractResolversFromSchema = extractResolversFromSchema;
//# sourceMappingURL=extract-resolvers-from-schema.js.map